@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_FEEDLISTMANAGEMENTINTERFACE_H
-#define AKREGATOR_FEEDLISTMANAGEMENTINTERFACE_H
+#pragma once
 
 #include "akregatorinterfaces_export.h"
 
@@ -35,4 +34,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_FEEDLISTMANAGEMENTINTERFACE_H
